==> postgrest-6.0.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 6.0.0
id: postgrest-6.0.0-6nl4o7mHjmkBuPN3UVs4JE
key: postgrest-6.0.0-6nl4o7mHjmkBuPN3UVs4JE
license: MIT
maintainer: Steve Chávez <stevechavezast@gmail.com>
author: Joe Nelson, Adam Baker
homepage: https://postgrest.org
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Executable, PostgreSQL, Network APIs
abi: 97fb3b1c895bc92de04b7ec013f3e152
exposed: True
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
import-dirs: /usr/lib/ghc-8.6.5/site-local/postgrest-6.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/postgrest-6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/postgrest-6.0.0
hs-libraries: HSpostgrest-6.0.0-6nl4o7mHjmkBuPN3UVs4JE
depends:
    HTTP-4000.3.14-2Ay04JNrGqV5tzDyIuQLXm
    Ranged-sets-0.4.0-2PchdoGuiayH3uspliUnwe
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    cassava-0.5.1.0-HsowyrmrG8l9Sai4EqSHbY
    configurator-pg-0.1.0.3-V2s5d8i7ACJVwT4g8Jz8L containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    contravariant-extras-0.3.4-35VdvcJZeo7BMor95g7S78
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    either-5.0.1.1-3snIebsA1WrDy3XGs2DL02
    gitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
    hasql-1.4-46WwBuBaWDL9DZYiklOqf0
    hasql-pool-0.5.1-9QRROydHTVCCkNKP3RXE0z
    hasql-transaction-0.7.2-7nOTSwsvCnu86ZQ5qI420d
    heredoc-0.2.0.0-5CGfN4QKKxO6xWz8UL0AnE
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    insert-ordered-containers-0.2.2-1z0z75CNMen94C1DYQINhp
    interpolatedstring-perl6-1.0.1-5sLdNsS1FGEHitzOZRXrri
    jose-0.7.0.0-AHIhHrmVYy72YkWSIfqHl4
    lens-4.17.1-8T170y2T2LJ1zUvkbQ6p47
    lens-aeson-1.0.2-I1z0FwUIZKeEXdBSMGUfZx
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    parsec-3.1.13.0 protolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    swagger2-2.3.1.1-3VtRSJ6NhHs8GkyMTSWEEZ text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-cors-0.2.7-KbupsdQ0ew97grCGJJX2rX
    wai-extra-3.0.28-F2XLLZJGOHkHVDuOrzgtkZ
    wai-middleware-static-0.8.2-3u8e1sPgjCXIQtbeYjJmjI
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> postgrest-6.0.0-20-x86_64.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 6.0.0
id: postgrest-6.0.0-6LeVowRkt6XL5F8GPqjGU5
key: postgrest-6.0.0-6LeVowRkt6XL5F8GPqjGU5
license: MIT
maintainer: Steve Chávez <stevechavezast@gmail.com>
author: Joe Nelson, Adam Baker
homepage: https://postgrest.org
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Executable, PostgreSQL, Network APIs
abi: 4b620c421a72b154c72f2a1ee23c79b1
exposed: True
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
import-dirs: /usr/lib/ghc-8.6.5/site-local/postgrest-6.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/postgrest-6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/postgrest-6.0.0
hs-libraries: HSpostgrest-6.0.0-6LeVowRkt6XL5F8GPqjGU5
depends:
    HTTP-4000.3.14-BxBq1EUGJNf3xmmQcCnXFs
    Ranged-sets-0.4.0-2PchdoGuiayH3uspliUnwe
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    cassava-0.5.1.0-HsowyrmrG8l9Sai4EqSHbY
    configurator-pg-0.1.0.3-V2s5d8i7ACJVwT4g8Jz8L containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    contravariant-extras-0.3.4-35VdvcJZeo7BMor95g7S78
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    either-5.0.1.1-EOMINiddEArIdyO4h91vLl
    gitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
    hasql-1.4-KJ015glGHKkJWlLwOOj4G9
    hasql-pool-0.5.1-I2FzqbqGzfB1VTNG8Nsqnv
    hasql-transaction-0.7.2-8KYdfDb4hXr5xyD2uhNPn5
    heredoc-0.2.0.0-5CGfN4QKKxO6xWz8UL0AnE
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    insert-ordered-containers-0.2.2-9UNPWZu5rEG9gjo8h2Xt95
    interpolatedstring-perl6-1.0.1-5sLdNsS1FGEHitzOZRXrri
    jose-0.7.0.0-GGYg66l5kSLKxFTTfg9I6U
    lens-4.17.1-ENKPXwJVBySCOhb6zFHax3
    lens-aeson-1.0.2-DXiCNIdSrMC40DO94Z5N2E
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    parsec-3.1.13.0 protolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    swagger2-2.3.1.1-4SNpLCUI55hEuLpIV1ZqBV text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-cors-0.2.7-KbupsdQ0ew97grCGJJX2rX
    wai-extra-3.0.28-F2XLLZJGOHkHVDuOrzgtkZ
    wai-middleware-static-0.8.2-3u8e1sPgjCXIQtbeYjJmjI
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
